==> rewrite-analysis-2.6.1-sources.jar: org/openrewrite/analysis/dataflow/global/RenderGlobalFlowPaths.java <==
/*
 * Copyright 2023 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.analysis.dataflow.global;

import lombok.AllArgsConstructor;
import org.openrewrite.java.JavaIsoVisitor;
import org.openrewrite.java.tree.Expression;
import org.openrewrite.java.tree.J;
import org.openrewrite.marker.SearchResult;

@AllArgsConstructor
public class RenderGlobalFlowPaths<P> extends JavaIsoVisitor<P> {
    GlobalDataFlow.Accumulator acc;

    @Override
    public Expression visitExpression(Expression expression, P p) {
        Expression e = super.visitExpression(expression, p);
        if (acc.isSource(getCursor())) {
            e = SearchResult.mergingFound(e, "source");
        }
        if (acc.isSink(getCursor())) {
            e = SearchResult.mergingFound(e, "sink");
        }
        if (expression != e) {
            return e;
        }
        if (acc.isFlowParticipant(getCursor())) {
            return SearchResult.found(e);
        }
        return e;
    }

    @Override
    public J.VariableDeclarations.NamedVariable visitVariable(J.VariableDeclarations.NamedVariable variable, P p) {
        J.VariableDeclarations.NamedVariable v = super.visitVariable(variable, p);
        if (acc.isSource(getCursor())) {
            v = SearchResult.mergingFound(v, "source");
        }
        if (acc.isSink(getCursor())) {
            v = SearchResult.mergingFound(v, "sink");
        }
        if (variable != v) {
            return v;
        }
        if (acc.isFlowParticipant(getCursor())) {
            return SearchResult.found(v);
        }
        return v;
    }
}

==> rewrite-analysis-2.29.0-sources.jar: org/openrewrite/analysis/dataflow/global/RenderGlobalFlowPaths.java <==
/*
 * Copyright 2023 the original author or authors.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * https://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.openrewrite.analysis.dataflow.global;

import lombok.AllArgsConstructor;
import org.openrewrite.java.JavaIsoVisitor;
import org.openrewrite.java.tree.Expression;
import org.openrewrite.java.tree.J;
import org.openrewrite.marker.SearchResult;

@AllArgsConstructor
public class RenderGlobalFlowPaths<P> extends JavaIsoVisitor<P> {
    GlobalDataFlow.Accumulator acc;

    @Override
    public Expression visitExpression(Expression expression, P p) {
        Expression e = super.visitExpression(expression, p);
        boolean marked = false;
        if (acc.isSource(getCursor())) {
            e = SearchResult.mergingFound(e, "source");
            marked = true;
        }
        if (acc.isSink(getCursor())) {
            e = SearchResult.mergingFound(e, "sink");
            marked = true;
        }
        if (marked) {
            return e;
        }
        if (acc.isFlowParticipant(getCursor())) {
            return SearchResult.found(e);
        }
        return e;
    }

    @Override
    public J.VariableDeclarations.NamedVariable visitVariable(J.VariableDeclarations.NamedVariable variable, P p) {
        J.VariableDeclarations.NamedVariable v = super.visitVariable(variable, p);
        boolean marked = false;
        if (acc.isSource(getCursor())) {
            v = SearchResult.mergingFound(v, "source");
            marked = true;
        }
        if (acc.isSink(getCursor())) {
            v = SearchResult.mergingFound(v, "sink");
            marked = true;
        }
        if (marked) {
            return v;
        }
        if (acc.isFlowParticipant(getCursor())) {
            return SearchResult.found(v);
        }
        return v;
    }
}
